import peasy.test.*;
import peasy.org.apache.commons.math.*;
import peasy.*;
import peasy.org.apache.commons.math.geometry.*;


// setting up PeasyCam
PeasyCam cam;
color prel = color(54,23,18);
color pgov = color(70,32,41);
color phum = color(75,48,69);
color econ = color(65,68,94);
color pter = color(37,89,107);
color etrd = color(3,108,105); 
color pinr = color(43,125,89);
color efin = color(94,137,66);
color eaid = color(150,143,51);
color asec = color(207,142,63);
color marr = color(255,138,104);

color enrg = color(19, 77, 13);


color col;
// including  ControlP5

import controlP5.*;
ControlP5 controlP5;

PMatrix3D currCameraMatrix;
PGraphics3D g3; 

//control check
boolean prel_type = false;
boolean enrg_type = false;
boolean pgov_type = false;
boolean phum_type = false;
boolean econ_type = false;
boolean pter_type = false;
boolean etrd_type = false;
boolean pinr_type = false;
boolean efin_type = false;
boolean eaid_type = false;
boolean asec_type = false;
boolean marr_type = false;

//draw check

//color 
String var_tag; 
IntDict g_count; 

int p5Margin = 10;
int p5Distance = 10;

int buttonWidth = 70;
int buttonHeight = 20;

PFont font1 = createFont("Helvetica",12, true);
PFont font2 = createFont("Lato",70, true);
PFont font3 = createFont("Lato",30, true);

ArrayList<String> tag_list = new ArrayList<String>(10);

Table allCables;
int count, i=0;
HashMap<String, Cable> cableList = new HashMap<String, Cable>();
ArrayList<Cable> allSources = new ArrayList<Cable>();

void setup() {
  size(1000, 1000, P3D);
  background(80); 
  noSmooth();
  frameRate(10);
  allCables = loadTable("10.csv", "header");
  makeHash();
  arrange();
  createIntDict();
  cam = new PeasyCam(this,0,0,0,800);
  cam.setMaximumDistance(1000);
  g3 = (PGraphics3D)g;
  setupGUI();  
}

void makeHash() {
  String n;
  String y;
  String z;
  for ( TableRow row : allCables.rows ())
  {
    n = row.getString("source");
    y = row.getString("date");    
    z = row.getString("tags");
    //println("tags: "+ z);  
    String [] tags = split(z,", ");
 
    

//println("source: "+ n);
    if (!cableList.containsKey(n))
    {
      Cable c = new Cable(n, y, tags);
      cableList.put(n, c);
      allSources.add(c);
      //println("Cable souce: " + c.source);
    }
  }
 
}

void createIntDict()
{
  g_count = new IntDict();
  for(TableRow row: allCables.rows())
  {
    String n = row.getString("source");
    if(g_count.hasKey(n))
    {
      g_count.increment(n); 
    }else{
      g_count.set(n,1);
      count++;
    }
  }
}

void arrange()
{
  int size = 0;
  for (Cable c : allSources) 
  {
    float t = map(i, 0, cableList.size()/2, -TAU/4, 3*TAU/4);
    float rad = 350;
    c.rot = t;
    //println("t " + t);
    c.pos.x = cos(t) * rad;
    c.pos.y = sin(t) * rad;
    size = size + 5;
    c.pos.z = size;
    i++;
  }
}


void draw()
{
  background(150);
  //translate(width/2, height/2);
  String[] sources = g_count.keyArray();
  int[] num_cables = g_count.valueArray();
  for (Cable c : allSources)
  {
    c.createNetwork();
    int amount=0;
    float thickness = 0;
    //println("c.rot" + c.rot);
       
    //println("pos.x " + c.pos.x + " pos.y " + c.pos.y);
    if(g_count.hasKey(c.source))
    {
      amount = g_count.get(c.source);
      println("value", amount);
    }
    if(amount < 100){
      thickness = map(amount, 1, 100, .1, 10);
    }else{
      thickness = 11;
    }
//    println("thickness: " + thickness);
boolean has_prel = false;
boolean has_enrg = false;
boolean has_pgov = false;
boolean has_phum = false;
boolean has_econ = false;
boolean has_pter = false;
boolean has_etrd = false;
boolean has_pinr = false;
boolean has_efin = false;
boolean has_eaid = false;
boolean has_asec = false;
boolean has_marr = false;

    line(c.pos.x+1, c.pos.y, c.pos.z, 0, 0, height/2);
    strokeWeight(thickness);
    if(prel_type){
      for(int j  = 0; j < c.tags.length; j++)
      {
        if(c.tags[j].equals("PREL")){
          has_prel = true;
          break;
         }
      }
    }else if(enrg_type){
      for(int j  = 0; j < c.tags.length; j++)
      {
        if(c.tags[j].equals("ENRG")){
          has_enrg = true;
          break;
         }
      } 
    }else if(pgov_type){
      for(int j  = 0; j < c.tags.length; j++)
      {
        if(c.tags[j].equals("PGOV")){
          has_pgov = true;
          break;
         }
      } 
    }else if(phum_type){
      for(int j  = 0; j < c.tags.length; j++)
      {
        if(c.tags[j].equals("PHUM")){
          has_phum = true;
          break;
         }
      } 
    }else if(econ_type){
      for(int j  = 0; j < c.tags.length; j++)
      {
        if(c.tags[j].equals("ECON")){
          has_econ = true;
          break;
         }
      } 
    }else if(pter_type){
      for(int j  = 0; j < c.tags.length; j++)
      {
        if(c.tags[j].equals("PTER")){
          has_pter = true;
          break;
         }
      } 
    }else if(etrd_type){
      for(int j  = 0; j < c.tags.length; j++)
      {
        if(c.tags[j].equals("ETRD")){
          has_etrd = true;
          break;
         }
      } 
    }else if(pinr_type){
      for(int j  = 0; j < c.tags.length; j++)
      {
        if(c.tags[j].equals("PINR")){
          has_pinr = true;
          break;
         }
      } 
    }else if(efin_type){
      for(int j  = 0; j < c.tags.length; j++)
      {
        if(c.tags[j].equals("EFIN")){
          has_efin = true;
          break;
         }
      } 
    }else if(eaid_type){
      for(int j  = 0; j < c.tags.length; j++)
      {
        if(c.tags[j].equals("EAID")){
          has_eaid = true;
          break;
         }
      } 
    }else if(asec_type){
      for(int j  = 0; j < c.tags.length; j++)
      {
        if(c.tags[j].equals("ASEC")){
          has_asec = true;
          break;
         }
      } 
    }else if(marr_type){
      for(int j  = 0; j < c.tags.length; j++)
      {
        if(c.tags[j].equals("MARR")){
          has_marr = true;
          break;
         }
      } 
    }




    if(has_prel)
    {
      stroke(prel);
    }else if(has_enrg){
      stroke(enrg);
    }else if(has_pgov){
      stroke(pgov);
    }else if(has_phum){
      stroke(phum);
    }else if(has_econ){
      stroke(econ);
    }else if(has_pter){
      stroke(pter);
    }else if(has_etrd){
      stroke(etrd);
    }else if(has_pinr){
      stroke(pinr);
    }else if(has_efin){
      stroke(efin);
    }else if(has_eaid){
      stroke(eaid);
    }else if(has_asec){
      stroke(asec);
    }else if(has_marr){
      stroke(marr);
    }else{
      stroke(col);
    }
  }
  
  
/* if(prel_type)
  {
    boolean has = false;
    for(Cable c : allSources)
    {
     for(int i = 0; i<c.tags.length; i++)
      {
        if(c.tags[i].equals("ENRG"))
        {
          has = true;
      //    println(c.tags[i]);
        }
      } 
      if(has)
      {
        line(c.pos.x, c.pos.y, c.pos.z, 0, 0, height/2);
        stroke(prel);
      }
    }
  }
 */
// println(g_count);
    drawGUI();  

}

